@@ -3,7 +3,7 @@ doc
 """
 
 # message module
-from .schemas.types import (   # type: ignore
+from .schemas.types import (  # type: ignore
 
     # Message
     MessageType,
@@ -76,13 +76,20 @@ from .schemas.event import (
     EventRoomJoinPayload,
     EventRoomInvitePayload,
 
-
     EventMessagePayload,
     EventHeartbeatPayload,
     EventFriendshipPayload,
     EventErrorPayload
 )
 
+from .exceptions import (
+    WechatyPuppetError,
+    WechatyPuppetConfigurationError,
+    WechatyPuppetGrpcError,
+    WechatyPuppetOperationError,
+    WechatyPuppetPayloadError,
+)
+
 from .logger import get_logger
 
 __all__ = [
@@ -134,6 +141,12 @@ __all__ = [
     'ImageType',
     'EventType',
 
+    'WechatyPuppetError',
+    'WechatyPuppetConfigurationError',
+    'WechatyPuppetGrpcError',
+    'WechatyPuppetOperationError',
+    'WechatyPuppetPayloadError',
+
     'get_logger'
 
 ]
